## UnscentedKalmanFilter

### Introduction and Overview

This implements the unscented Kalman filter.

## API Reference

### UnscentedKalmanFilter

::: bayesian_filters.kalman.UKF.UnscentedKalmanFilter

### Merwe Scaled Sigma Points

::: bayesian_filters.kalman.sigma_points.MerweScaledSigmaPoints

### Julier Sigma Points

::: bayesian_filters.kalman.sigma_points.JulierSigmaPoints

### Simplex Sigma Points

::: bayesian_filters.kalman.sigma_points.SimplexSigmaPoints
